@@ -1,3 +1,10 @@
+# base match.arg cannot match NA ???
+match.arg <- function(arg,choices,...)
+{
+  if(is.na(arg) && any(is.na(choices))) { return(NA) }
+  else { return(base::match.arg(arg,choices,...)) }
+}
+
 # is a package installed?
 is.installed <- function(pkg) is.element(pkg, utils::installed.packages()[,1])
 
@@ -153,7 +160,7 @@ cov.loglike <- function(hess,grad=rep(0,nrow(hess)))
   if(all(diag(hess)>0))
   {
     COV <- try(PDsolve(hess))
-    if(class(COV)=="matrix") { return(COV) }
+    if(class(COV)=="matrix" && all(diag(COV)>0)) { return(COV) }
   }
   # one of the curvatures is negative or close to negative
   # return something sensible just in case we are on a boundary and this makes sense
@@ -175,7 +182,7 @@ cov.loglike <- function(hess,grad=rep(0,nrow(hess)))
 
   EIGEN <- eigen(hess)
   values <- EIGEN$values
-  if(any(values<=0)) { warning("MLE is near a boundary or optim failed.") }
+  if(any(values<=0)) { warning("MLE is near a boundary or optim() failed.") }
   values <- clamp(values,0,Inf)
   vectors <- EIGEN$vectors
 
@@ -292,3 +299,13 @@ rename <- function(object,name1,name2)
   names(object)[IND] <- name2
   return(object)
 }
+
+
+# glue strings together if they different
+glue <- function(...)
+{
+  x <- c(...) # removes NULLs
+  x <- unique(x) # removes matchs
+  x <- paste(x) # paste different strings together
+  return(x)
+}
